@@ -25,7 +25,7 @@ CONFIG_FILE = "{0}/.cam.conf".format(HOME)
 DEFAULT_CONF="""server: 127.0.0.1
 port: 3857
 password: 0a8148539c426d7c008433172230b551
-host_lock_time: 60
+lock_time: 60
 """
 
 def get_time():
@@ -172,7 +172,7 @@ class CAM(object):
             pass
         elif self._node_status['resource'] <= 0:
             self._node_status['node_status'] = "WAIT RESOURCE"
-        elif self._check_host_lock(self._node_status['host_lock_time']):
+        elif self._check_host_lock(self._node_status['lock_time']):
             self._node_status['node_status'] = "WAIT LOCK"
         else:
             self._node_status['node_status'] = "IDLE"
@@ -193,7 +193,9 @@ class CAM(object):
         try:
             len_to_node = self._redis.llen(f"to_{get_node_name()}")
             if len_to_node != 0:
-                return json.loads(self._redis.rpop(f"to_{get_node_name()}"))
+                msg = self._redis.rpop(f"to_{get_node_name()}")
+                if msg is not None:
+                    return json.loads(msg)
             msg = self._watcher.get_message(timeout = timeout)
             len_task_pending = self._redis.llen("task_pending")
             if msg == None:
@@ -236,7 +238,7 @@ class CAM(object):
         self._log_sys_info()
 
     
-    def worker(self, resource=1, prefix="", priority=10, suffix = "", server = None, port = None, host_lock_time=5):
+    def worker(self, resource=1, prefix="", priority=10, suffix = "", server = None, port = None, lock_time=5):
         """
          Start the worker. 
         <br>`cam worker "some start condition"`
@@ -254,12 +256,13 @@ class CAM(object):
             if server is not None or port is not None:
                 self._redis = redis.StrictRedis(host=self._conf["server"], port=self._conf["port"], password=self._conf["password"], db=0, encoding="utf-8")
             self._log_sys_info()
-            self._node_status = {"node" : get_node_name(), "host" : get_host_name(), "priority" : priority, "prefix": prefix, "suffix": suffix, "node_status" : "IDLE", "host_lock_time" : host_lock_time, "start_time": get_time(), "pwd" : os.getcwd(), "version" : __version__, "task" : {}}
+            self._node_status = {"node" : get_node_name(), "host" : get_host_name(), "priority" : priority, "prefix": prefix, "suffix": suffix, "node_status" : "IDLE", "lock_time" : lock_time, "start_time": get_time(), "pwd" : os.getcwd(), "version" : __version__, "task" : {}}
             self._redis.config_set("notify-keyspace-events", "KEA")
             self._watcher = self._redis.pubsub()
             self._watcher.subscribe(["__keyspace@0__:task_pending", f"__keyspace@0__:to_{get_node_name()}"])
             self._resource_cond = resource
             os.system("tmux rename-window cam%d"%os.getpid())
+            self._update_node_status()
         except Exception as e:
             print(e)
             log_warn(f"Cannot connect to the server {self._conf['server']}:{self._conf['port']}")
